<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Parser_Archive
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Parser_Archive
{

    /**
     * Feed matches
     * @var array
     */
    protected $_matches = array();

    /**
     * Feed RegEx
     * @var string
     */
    protected $_regex = '/\[\{archive.*\}\]/';

    /**
     * Content to evaluate
     * @var string
     */
    protected $_content = null;

    /**
     * URL request
     * @var string
     */
    protected $_url = null;

    /**
     * Constructor
     *
     * Instantiate the feed parser object.
     *
     * @param  string $content
     * @param  string $url
     * @return void
     */
    public function __construct($content, $url = null)
    {

        // Perform a preg_match_all to look for any feed tags within the content, then parse the content.
        $this->_content = $content;
        preg_match_all($this->_regex, $this->_content, $this->_matches);
        $this->_parse();

    }

    /**
     * Static method to instantiate the feed parser object
     * and return the parsed string.
     *
     * @param  string $cont
     * @param  string $u
     * @return Phire_Parser_Feed
     */
    public static function init($cont, $u = null)
    {

        return new self($cont, $u);

    }

    /**
     * Set content within the content property.
     *
     * @param  string $subject
     * @param  string $replace
     * @return void
     */
    public function setContent($subject, $replace)
    {

        $this->_content = str_replace($subject, $replace, $this->_content);

    }

    /**
     * Get content within the content property.
     *
     * @return string
     */
    public function getContent()
    {

        return $this->_content;

    }

    /**
     * Renders any feed elements within the content.
     *
     * @return void
     */
    protected function _parse()
    {

        // If feed tag elements are found, format and set in content.
        if (isset($this->_matches[0][0])) {

            foreach ($this->_matches[0] as $value) {

                $sess = Moc10_Session::getInstance();
                $memSQL = (!isset($sess->member_id) && !isset($sess->user_id)) ? 'AND page_access != \'Private\' ' : '';
                $content = null;
                $pages = new Phire_Table_Pages();
                // Get all archives based on year.
                if ($value == '[{archive}]') {
                    $years = array();
                    $sql = "SELECT * FROM " . DB_PREFIX . "pages WHERE published = 'Yes' {$memSQL}ORDER BY created DESC";
                    $pages->execute($sql);
                    if (isset($pages->rows)) {
                        foreach ($pages->rows as $page) {
                            $year = substr($page->created, 0, 4);
                            if (array_key_exists($year, $years)) {
                                $years[$year]++;
                            } else {
                                $years[$year] = 1;
                            }
                        }
                        if (count($years) > 0) {
                            $content = "    <ul class=\"archiveList\">\n";
                            foreach ($years as $year => $num) {
                                $content .= "        <li><a href=\"" . BASE_PATH . "/{$year}\">{$year}</a> ({$num})</li>\n";
                            }
                            $content .= "    </ul>\n";
                        }
                    }
                // Get all archives within a section.
                } else if (strpos($value, '_') != false){
                    $months = array();
                    $years = array();
                    $by_month = false;
                    $section_id = null;
                    $section_url = '';
                    $val = str_replace('}]', '', str_replace('[{', '', $value));
                    $valAry = explode('_', $val);
                    if ($valAry[1] == 'm') {
                        $by_month = true;
                        if (isset($valAry[2]) && is_numeric($valAry[2])) {
                            $section_id = $valAry[2];
                        }
                    } else if (is_numeric($valAry[1])) {
                        $section_id = $valAry[1];
                    }

                    if (!is_null($section_id)) {
                        $section = new Phire_Table_Sections();
                        $section->findById($section_id);
                        $section_url = ($section->section_url != '/') ? $section->section_url : '';

                        $child_sections = new Phire_Table_Sections();
                        $child_sections->findAll(null, 'parent_section_id', $section_id);
                        if (isset($child_sections->rows[0])) {
                            foreach ($child_sections->rows as $sect) {
                                $pg = new Phire_Table_Pages();
                                $pg->findAll(null, 'section_id', $sect->section_id);
                                if (isset($pg->rows[0])) {
                                    foreach ($pg->rows as $p) {
                                        $year = substr($p->created, 0, 4);
                                        $month = substr($p->created, 0, 7);
                                        if (array_key_exists($year, $years)) {
                                            $years[$year]++;
                                        } else {
                                            $years[$year] = 1;
                                        }
                                        if (array_key_exists($month, $months)) {
                                            $months[$month]++;
                                        } else {
                                            $months[$month] = 1;
                                        }
                                    }
                                }
                            }
                        }

                        $sql = "SELECT * FROM " . DB_PREFIX . "pages WHERE published = 'Yes' AND section_id = '" . (int)$section_id . "' {$memSQL}ORDER BY created DESC";
                        $pages->execute($sql);

                    } else {
                        $sql = "SELECT * FROM " . DB_PREFIX . "pages WHERE published = 'Yes' {$memSQL}ORDER BY created DESC";
                        $pages->execute($sql);
                    }

                    if (isset($pages->rows)) {
                        foreach ($pages->rows as $page) {
                            $year = substr($page->created, 0, 4);
                            $month = substr($page->created, 0, 7);
                            if (array_key_exists($year, $years)) {
                                $years[$year]++;
                            } else {
                                $years[$year] = 1;
                            }
                            if (array_key_exists($month, $months)) {
                                $months[$month]++;
                            } else {
                                $months[$month] = 1;
                            }
                        }
                    }
                    if ($by_month) {
                        if (count($months) > 0) {
                            krsort($months);
                            $content = "    <ul class=\"archiveList\">\n";
                            foreach ($months as $month => $num) {
                                $monthAry = explode('-', $month);
                                $formattedMonth = date('F', strtotime($month . '-01')) . ' ' . $monthAry[0];
                                $content .= "        <li><a href=\"" . BASE_PATH . $section_url . "/{$monthAry[0]}/{$monthAry[1]}\">{$formattedMonth}</a> ({$num})</li>\n";
                            }
                            $content .= "    </ul>\n";
                        }
                    } else {
                        if (count($years) > 0) {
                            krsort($years);
                            $content = "    <ul class=\"archiveList\">\n";
                            foreach ($years as $year => $num) {
                                $content .= "        <li><a href=\"" . BASE_PATH . $section_url . "/{$year}\">{$year}</a> ({$num})</li>\n";
                            }
                            $content .= "    </ul>\n";
                        }
                    }
                }

                $this->setContent($value, $content);

            }

        }

    }

}
