<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Parser_Recent
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Parser_Recent
{

    /**
     * Feed matches
     * @var array
     */
    protected $_matches = array();

    /**
     * Feed RegEx
     * @var string
     */
    protected $_regex = '/\[\{recent.*\}\]/';

    /**
     * Content to evaluate
     * @var string
     */
    protected $_content = null;

    /**
     * URL request
     * @var string
     */
    protected $_url = null;

    /**
     * Constructor
     *
     * Instantiate the feed parser object.
     *
     * @param  string $content
     * @param  string $url
     * @return void
     */
    public function __construct($content, $url = null)
    {

        // Perform a preg_match_all to look for any feed tags within the content, then parse the content.
        $this->_content = $content;
        preg_match_all($this->_regex, $this->_content, $this->_matches);
        $this->_parse();

    }

    /**
     * Static method to instantiate the feed parser object
     * and return the parsed string.
     *
     * @param  string $cont
     * @param  string $u
     * @return Phire_Parser_Feed
     */
    public static function init($cont, $u = null)
    {

        return new self($cont, $u);

    }

    /**
     * Set content within the content property.
     *
     * @param  string $subject
     * @param  string $replace
     * @return void
     */
    public function setContent($subject, $replace)
    {

        $this->_content = str_replace($subject, $replace, $this->_content);

    }

    /**
     * Get content within the content property.
     *
     * @return string
     */
    public function getContent()
    {

        return $this->_content;

    }

    /**
     * Renders any feed elements within the content.
     *
     * @return void
     */
    protected function _parse()
    {

        // If feed tag elements are found, format and set in content.
        if (isset($this->_matches[0][0])) {

            foreach ($this->_matches[0] as $value) {

                $sess = Moc10_Session::getInstance();
                $memSQL = (!isset($sess->member_id) && !isset($sess->user_id)) ? 'AND page_access != \'Private\' ' : '';
                $content = null;
                $pages = new Phire_Table_Pages();

                $recentAry = explode('_', Moc10_String::setString($value)->replace('[{', '')->replace('}]', ''));
                if ($recentAry[1] == 'lg') {
                    $sql = "SELECT * FROM " . DB_PREFIX . "pages WHERE published = 'Yes' {$memSQL}ORDER BY created DESC LIMIT " . (int)$recentAry[2];
                    $pages->execute($sql);
                    if (isset($pages->rows)) {
                        $content = "    <ul id=\"recentListLg\">\n";
                        foreach ($pages->rows as $page) {
                            // Title, Date, Section, Tags, Excerpt
                            $sectionTitle = null;
                            $tags = null;
                            if ($page->section_id != 0) {
                                $section = new Phire_Table_Sections();
                                $section->findById($page->section_id);
                                if (isset($section->section_id)) {
                                    $sectionTitle = ' in <a href="' . BASE_PATH . $section->section_url . '">' . $section->section_title . '</a>';
                                }
                            }
                            if ($page->page_tags != '') {
                                $tagIds = explode('|', $page->page_tags);
                                $tagsObj = new Phire_Table_Tags();
                                $tagSQL = "SELECT * FROM " . DB_PREFIX . "tags WHERE tag_id = " . implode(' OR tag_id = ', $tagIds) . "";
                                $tagsObj->execute($tagSQL);
                                if (isset($tagsObj->rows[0])) {
                                    $tagAry = array();
                                    foreach ($tagsObj->rows as $t) {
                                        $tagAry[] = '<a href="' . BASE_PATH . '/tag/' . $t->tag . '">' . $t->tag . '</a>';
                                    }
                                    $tags = '<div class="recentTags"><strong>Tags:</strong> ' . implode(', ', $tagAry) . '</div>';
                                }
                            }
                            $content .= "                    <li>\n                        <h3><a href=\"" . BASE_PATH . $page->page_url . "\">{$page->page_title}</a></h3>(" . date('F j Y', strtotime($page->created)) . "{$sectionTitle})\n                        <div class=\"recentDiv\">" . Moc10_String::setString($page->page_content)->striptags()->sub(0, 250) . "... (<a href=\"" . BASE_PATH . $page->page_url . "\">Read More</a>)</div>{$tags}\n                    </li>\n";
                        }
                        $content .= "    </ul>\n";
                    }
                } else if ($recentAry[1] == 'sm') {
                    $sql = "SELECT * FROM " . DB_PREFIX . "pages WHERE published = 'Yes' {$memSQL}ORDER BY created DESC LIMIT " . (int)$recentAry[2];
                    $pages->execute($sql);
                    if (isset($pages->rows)) {
                        $content = "                <ul id=\"recentListSm\">\n";
                        foreach ($pages->rows as $page) {
                            // Title, Date, Section
                            $sectionTitle = null;
                            if ($page->section_id != 0) {
                                $section = new Phire_Table_Sections();
                                $section->findById($page->section_id);
                                if (isset($section->section_id)) {
                                    $sectionTitle = ' in <a href="' . BASE_PATH . $section->section_url . '">' . $section->section_title . '</a>';
                                }
                            }
                            $content .= "                    <li>\n                        <h4><a href=\"" . BASE_PATH . $page->page_url . "\">{$page->page_title}</a></h4>(" . date('F j Y', strtotime($page->created)) . "{$sectionTitle})\n                    </li>\n";
                        }
                        $content .= "                </ul>\n";
                    }
                }

                $this->setContent($value, $content);

            }

        }

    }

}
