<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Parser_Session
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Parser_Session
{

    /**
     * Session matches
     * @var array
     */
    protected $_matches = array();

    /**
     * Session RegEx for open tags
     * @var string
     */
    protected $_open_regex = '/\[\{sess\}\]/msi';

    /**
     * Session RegEx for close tags
     * @var string
     */
    protected $_close_regex = '/\[\{\/sess\}\]/msi';

    /**
     * Content to evaluate
     * @var string
     */
    protected $_content = null;

    /**
     * URL request
     * @var string
     */
    protected $_url = null;

    /**
     * Constructor
     *
     * Instantiate the session parser object.
     *
     * @param  string $content
     * @param  string $url
     * @return void
     */
    public function __construct($content, $url = null)
    {

        $this->_content = $content;

        $open_matches = array();
        $close_matches = array();
        $merge = array();

        // Perform a preg_match_all to look for any session tags within the content.
        preg_match_all($this->_open_regex, $this->_content, $open_matches, PREG_OFFSET_CAPTURE);
        preg_match_all($this->_close_regex, $this->_content, $close_matches, PREG_OFFSET_CAPTURE);

        // If matches are found, format and merge the results.
        if ((isset($open_matches[0][0])) && (isset($close_matches[0][0]))) {
            foreach ($open_matches[0] as $key => $value) {
                $merge[] = array($open_matches[0][$key][0] => $open_matches[0][$key][1], $close_matches[0][$key][0] => $close_matches[0][$key][1]);
            }
        }
        foreach ($merge as $match) {
            $this->_matches[] = substr($this->_content, $match['[{sess}]'], (($match['[{/sess}]'] - $match['[{sess}]']) + 9));
        }

        // Parse the content.
        $this->_parse();

    }

    /**
     * Static method to instantiate the session parser object
     * and return the parsed string.
     *
     * @param  string $cont
     * @param  string $u
     * @return Phire_Parser_Session
     */
    public static function init($cont, $u = null)
    {

        return new self($cont, $u);

    }

    /**
     * Set content within the content property.
     *
     * @param  string $subject
     * @param  string $replace
     * @return void
     */
    public function setContent($subject, $replace)
    {

        $this->_content = str_replace($subject, $replace, $this->_content);

    }

    /**
     * Get content within the content property.
     *
     * @return string
     */
    public function getContent()
    {

        return $this->_content;

    }

    /**
     * Renders any session elements within the content.
     *
     * @return void
     */
    protected function _parse()
    {

        // If session tag elements are found, format and set in content.
        if (isset($this->_matches[0])) {

            $sess = Moc10_Session::getInstance();

            foreach ($this->_matches as $value) {

                // Get the session matches conditions.
                $sess_string = str_replace('[{sess}]', '', $value);
                $sess_string = str_replace('[{/sess}]', '', $sess_string);
                $sess_actions = explode('[{or}]', $sess_string);

                // If the member is logged in.
                if (isset($sess->member_id)) {
                    $sess_set_string = str_replace('[{username}]', $sess->username, $sess_actions[0]);
                    $sess_set_string = str_replace('[{member_id}]', $sess->member_id, $sess_set_string);
                    $sess_set_string = str_replace('[{email}]', $sess->email, $sess_set_string);
                    $sess_set_string = str_replace('[{fname}]', $sess->fname, $sess_set_string);
                    $sess_set_string = str_replace('[{lname}]', $sess->lname, $sess_set_string);
                    $this->setContent($value, $sess_set_string);
                // Else, if the user is logged in.
                } else if (isset($sess->user_id)) {
                    $sess_set_string = str_replace('[{username}]', $sess->username, $sess_actions[0]);
                    $sess_set_string = str_replace('[{user_id}]', $sess->user_id, $sess_set_string);
                    $sess_set_string = str_replace('[{email}]', $sess->email, $sess_set_string);
                    $sess_set_string = str_replace('[{fname}]', $sess->fname, $sess_set_string);
                    $sess_set_string = str_replace('[{lname}]', $sess->lname, $sess_set_string);
                    $this->setContent($value, $sess_set_string);
                // Else, if no one is logged in.
                } else {
                    $this->setContent($value, $sess_actions[1]);
                }

            }

        }

    }

}
