<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Search
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Search
 *
 * @category   Phire
 * @package    Phire_Search
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Search extends Phire_Template
{

    /**
     * Search keywords
     * @var string
     */
    protected $_keywords = null;

    /**
     * Site object
     * @var Phire_Table_Site
     */
    protected $_site = null;

    /**
     * Constructor
     *
     * Instantiate the search object.
     *
     * @param  string $kwds
     * @param  string $url
     * @return void
     */
    public function __construct($kwds, $url = null)
    {

        parent::__construct();
        $this->_tmpl = Phire_Parser::getParser($this->_tmpl, $url)->getContent();
        $this->_keywords = (string)Moc10_String::setString($kwds)->escape(true)->striptags();

        $sess = Moc10_Session::getInstance();

        if ((isset($sess->keywords)) && ($sess->keywords != $this->_keywords) && (!isset($_GET['page']))) {
            unset($sess->search);
            unset($sess->keywords);
            unset($sess->search_title);
            unset($sess->search_sub_title);
        }

        // Get the site information.
        $this->_site = new Phire_Table_Sites();
        $this->_site->getSite();

        $this->setContent('[{page_charset}]', $this->_site->charset);
        $this->setContent('[{page_author}]', Moc10_String::setString($this->_site->default_author)->strip()->html());
        $this->setContent('[{page_keywords}]', Moc10_String::setString($this->_site->default_keywords)->strip()->html());
        $this->setContent('[{page_desc}]', Moc10_String::setString($this->_site->default_desc)->strip()->html());
        $this->setContent('[{page_robots}]', $this->_site->robots);
        $this->setContent('[{site_domain}]', $this->_site->site_domain);
        $this->setContent('[{site_tags}]', Phire_TagCloud::render($this->_site->site_id));
        $this->setContent('[{base_path}]', BASE_PATH);
        $this->setContent('[{sys_path}]', SYS_PATH);
        $this->setContent('[{content_path}]', CONTENT_PATH);

    }

    /**
     * Initialize the search template.
     *
     * @return void
     */
    public function init()
    {

        $sess = Moc10_Session::getInstance();
        $lang = new Phire_Language();
        $pg = (isset($_GET['page'])) ? $_GET['page'] : 1;

        // If no keywords are passed, display error.
        if (isset($sess->search)) {

            $sess->search_title = Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $lang->__('Search Results') . ' > "' . $sess->keywords . '"')->strip()->html();
            $sess->search_sub_title = 'Search Results &gt; "' .  $sess->keywords . '"';

            $this->setContent('[{page_title}]', $sess->search_title);
            $this->setContent('[{page_sub_title}]', $sess->search_sub_title);

            $searchResults = $sess->search->render($pg, ' | ', 'subLinkOn', 'subLinkOff', null, true);

        } else if ((is_null($this->_keywords)) || ($this->_keywords == '')) {

            $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $lang->__('Search Results') . ' > ' . $lang->__('Error'))->strip()->html());
            $this->setContent('[{page_sub_title}]', $lang->__('Search Results') . ' &gt; ' . $lang->__('Error'));
            $searchResults = "<!-- Search Results Begin Here //-->\n        <div id=\"searchContent\">\n            <p><strong>" . $lang->__('You must enter a search keyword.') . "</strong></p>\n        </div>\n<!-- Search Results End Here //-->";

        // Else, perform the search.
        } else {

            // Format the search results title.
            $sess->keywords = $this->_keywords;
            $sess->search_title = Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $lang->__('Search Results') . ' > "' . $this->_keywords . '"')->strip()->html();
            $sess->search_sub_title = $lang->__('Search Results') . ' &gt; "' . $this->_keywords . '"';

            $this->setContent('[{page_title}]', $sess->search_title);
            $this->setContent('[{page_sub_title}]', $sess->search_sub_title);

            // Get search results.
            $pages = new Phire_Table_Pages();
            if (isset($sess->user_id) || isset($sess->member_id)) {
                $pages->execute("SELECT * FROM " . DB_PREFIX . "pages WHERE (site_id = '" . $this->_site->site_id . "' AND published = 'Yes') AND (page_title LIKE '%" . $this->_keywords . "%' OR page_content LIKE '%" . $this->_keywords . "%')");
            } else {
                $pages->execute("SELECT * FROM " . DB_PREFIX . "pages WHERE page_access = 'Public' AND (site_id = '" . $this->_site->site_id . "' AND published = 'Yes') AND (page_title LIKE '%" . $this->_keywords . "%' OR page_content LIKE '%" . $this->_keywords . "%')");
            }

            // Get search results.
            $sections = new Phire_Table_Sections();
            if (isset($sess->user_id) || isset($sess->member_id)) {
                $sections->execute("SELECT * FROM " . DB_PREFIX . "sections WHERE site_id = '" . $this->_site->site_id . "' AND section_title LIKE '%" . $this->_keywords . "%'");
            } else {
                $sections->execute("SELECT * FROM " . DB_PREFIX . "sections WHERE section_access = 'Public' AND site_id = '" . $this->_site->site_id . "' AND section_title LIKE '%" . $this->_keywords . "%'");
            }

            $searchResults = '';
            $search_rows = array();

            // If found, format the search results.
            if (isset($pages->rows[0])) {

                $searchHeader = "<!-- Search Results Begin Here //-->\n        <div id=\"searchContent\">\n            [{page_links}]\n";
                $searchRowTmpl = "            <div class=\"searchResult\">\n                <a class=\"searchTitle\" href=\"[{page_url}]\">[{page_title}]</a>\n                [{summary}]\n            </div>\n";

                // If page results are found, format and set into the search rows array.
                foreach ($pages->rows as $page) {

                    // Set page title and URL.
                    $page_url = BASE_PATH . $page->page_url;
                    $page_title = Moc10_String::setString($page->page_title)->strip();

                    // Create page summary, stripping away JS tags and content, normal HTML tags and white space.
                    $page_content = Moc10_String::setString($page->page_content)->replace('[{page_sub_title}]', (string)Moc10_String::setString($page->page_title)->strip()->html())->preg('/<script(.*?)<\/script>/si', '')->striptags()->preg('/\[\{(.?)*\}\]/', '')->preg('/\s\s+/', '');

                    if ($page_content != '') {
                        $summary = ($page_content->ipos($this->_keywords) <= strlen($this->_keywords)) ? Moc10_String::setString('...' . $page_content->sub(0, 300) . '...') : Moc10_String::setString('...' . $page_content->sub(($page_content->ipos($this->_keywords) - 20), 300) . '...');
                    } else {
                        $summary = Moc10_String::setString('');
                    }
                    $summary = $summary->ireplace($this->_keywords, '<strong>' . $this->_keywords . '</strong>');

                    $search_rows[] = array('page_url' => $page_url,
                                           'page_title' => $page_title,
                                           'summary' => $summary);

                }

            }

            // If section results are found, format and set into the search rows array.
            if (isset($sections->rows[0])) {
                foreach ($sections->rows as $section) {

                    // Set section title and URL.
                    $section_url = BASE_PATH . $section->section_url;
                    $section_title = Moc10_String::setString($section->section_title)->strip()->html();

                    $search_rows[] = array('page_url' => $section_url,
                                           'page_title' => $section_title,
                                           'summary' => '');

                }

            }

            if (isset($search_rows[0])) {
                $searchFooter = "            [{page_links}]\n        </div>\n<!-- Search Results End Here //-->";

                // Get the site pagination limit.
                $pg_num = ($this->_site->site_pagination_limit != 0) ? $this->_site->site_pagination_limit : count($search_rows);
                $pg_range = ($this->_site->site_pagination_range != 0) ? $this->_site->site_pagination_range : null;

                // Render the page results.
                $sess->search = new Moc10_Session_Paginator($search_rows, $pg_num, $pg_range);
                $sess->search->setHeader($searchHeader);
                $sess->search->setRowTemplate($searchRowTmpl);
                $sess->search->setFooter($searchFooter);
                $searchResults = $sess->search->render($pg, ' | ', 'subLinkOn', 'subLinkOff', null, true);

            // Else format empty set.
            } else {
                $searchResults = "<!-- Search Results Begin Here //-->\n        <div id=\"searchContent\">\n            <p><strong>" . $lang->__('Sorry, no search results where found.') . "</strong></p>\n            <p>" . $lang->__('Please refine your search and try again.') . "</p>\n        </div>\n<!-- Search Results End Here //-->";
            }

            $log = new Phire_Table_SearchLog(array('site_id' => $this->_site->site_id,
                                                   'keywords' => $this->_keywords,
                                                   'results' => count($search_rows),
                                                   'search_datetime' => date('Y-m-d H:i:s')));
            $log->save();

        }

        $searchResults = str_replace('&query=/search', '', $searchResults);
        $searchResults = str_replace('index.php', 'search', $searchResults);
        $this->setContent('[{page_content}]', $searchResults);

    }

}
