<?php

/**
 * Phire System User Verify
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once dirname(__FILE__) . '/config.check.php';

// The URL should be /#type#/#action#/#id#/#hash#
// i.e. /user/verify/1001/a6ad00ac113a19d953efb91820d8788e2263b28a

$lang = new Phire_Language();
$urlParts = Moc10_String::setString($this->_url)->split('/');

$type = (isset($urlParts[1]) ? $urlParts[1] : '');
$action = (isset($urlParts[2]) ? $urlParts[2] : '');
$id = (isset($urlParts[3]) ? $urlParts[3] : '');
$hash = (isset($urlParts[4]) ? $urlParts[4] : '');


// Check if the variables are set properly.
if (($type != 'user') || ($id == '') || ($hash == '')) {

    header('Location: /');

} else {

    // Verify the user.
    try {

        $user = new Phire_Table_Users();

        if (isset($user)) {

            $user->findById($id);

            // Validate the attempted user email.
            if ((!isset($user->email)) || (sha1($user->email) != $hash)) {

                $admin_title = "Phire CMS &gt; " . $lang->__('User Verify') . " &gt; " . $lang->__('Error');
                include_once $_SERVER['DOCUMENT_ROOT'] . '/' . substr(BASE_PATH . SYS_PATH, 1) . '/core/includes/error.header.php';
                print("        <h2 class=\"redHeader\">Phire CMS &gt; " . $lang->__('User Verify') . " &gt; " . $lang->__('Error') . "</h2>\n");
                print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 150px 0;\">" . $lang->__('There was an error regarding your data while attempting to process your verification.') . "</p>\n");
                include_once $_SERVER['DOCUMENT_ROOT'] . '/' . substr(BASE_PATH . SYS_PATH, 1) . '/core/includes/footer.php';

            // Verify and save the user.
            } else {

                $user->verified = 'Yes';
                $user->save();

                $admin_title = "Phire CMS &gt; " . $lang->__('User Verify') . " &gt; " . $lang->__('Success');
                include_once $_SERVER['DOCUMENT_ROOT'] . '/' . substr(BASE_PATH . SYS_PATH, 1) . '/core/includes/header.php';
                print("        <h2 class=\"blueHeader\">Phire CMS &gt; " . $lang->__('User Verify') . " &gt; " . $lang->__('Success') . "</h2>\n");
                print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 150px 0;\">" . $lang->__('Thank You. You have successfully verified your email address. You may now %1login and use the system%2.', array("<a href=\"" . BASE_PATH . SYS_PATH . "/\">", "</a>")) . "</p>\n");
                include_once $_SERVER['DOCUMENT_ROOT'] . '/' . substr(BASE_PATH . SYS_PATH, 1) . '/core/includes/footer.php';

            }

        }

    // Else throw a exception/error.
    } catch (Exception $e) {

        $admin_title = "Phire CMS &gt; " . $lang->__('User Verify') . " &gt; " . $lang->__('Error');
        include_once $_SERVER['DOCUMENT_ROOT'] . '/' . substr(BASE_PATH . SYS_PATH, 1) . '/core/includes/error.header.php';
        print("        <h2 class=\"redHeader\">Phire CMS &gt; " . $lang->__('User Verify') . " &gt; " . $lang->__('Error') . "</h2>\n");
        print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 150px 0;\">" . $lang->__('There was a system error while attempting to process your verification.') . "</p>\n");
        include_once $_SERVER['DOCUMENT_ROOT'] . '/' . substr(BASE_PATH . SYS_PATH, 1) . '/core/includes/footer.php';

    }

}

?>